#
# spec file for package maven-plugin-plugin-bootstrap
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name maven-plugin-tools
%global artifactId maven-plugin-plugin
Name:           %{artifactId}-bootstrap
Version:        3.15.1
Release:        1.2.2.1.sr20250601
Summary:        Maven Plugin Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugin-tools/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugin-tools/%{base_name}/%{version}/%{base_name}-%{version}-source-release.zip
Source1:        %{base_name}-build.tar.xz
Patch0:         0002-Remove-dependency-on-jtidy.patch
# The maven-plugin-plugin is used to generate those descriptors, which
# creates a circular dependency of maven-plugin-plugin on itself.
# We generated those ones outside the rpm build for a bootstrap package.
Patch20:        maven-plugin-plugin-bootstrap-resouces.patch
BuildRequires:  ant
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-lib
BuildRequires:  maven-plugin-annotations
BuildRequires:  maven-plugin-tools-annotations
BuildRequires:  maven-plugin-tools-api
BuildRequires:  maven-plugin-tools-generators
BuildRequires:  maven-resolver-api
BuildRequires:  maven-resolver-util
BuildRequires:  plexus-build-api0
BuildRequires:  plexus-utils
BuildRequires:  plexus-velocity
BuildRequires:  sisu-plexus
BuildRequires:  unzip
BuildArch:      noarch

%description
The Plugin Plugin is used to create a Maven plugin descriptor for any Mojo's
found in the source tree, to include in the JAR. It is also used to generate
Xdoc files for the Mojos as well as for updating the plugin registry, the
artifact metadata and a generic help goal.

%prep
%setup -q -n %{base_name}-%{version} -a1
%patch -P 0 -p1
%patch -P 20

%pom_remove_plugin -r :maven-enforcer-plugin

%pom_xpath_inject "pom:project/pom:properties" "
    <project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
    <project.reporting.outputEncoding>UTF-8</project.reporting.outputEncoding>"

%pom_remove_dep org.junit:junit-bom
%pom_remove_dep :maven-plugin-tools-ant maven-plugin-plugin
%pom_remove_dep :maven-plugin-tools-beanshell maven-plugin-plugin

%build
mkdir -p lib
build-jar-repository -s lib \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-model \
    maven/maven-plugin-api \
    maven/maven-repository-metadata \
    maven/maven-settings \
    maven-plugin-tools/maven-plugin-annotations \
    maven-plugin-tools/maven-plugin-tools-api \
    maven-plugin-tools/maven-plugin-tools-generators \
    maven-resolver/maven-resolver-api \
    maven-resolver/maven-resolver-util \
    org.eclipse.sisu.plexus \
    plexus/plexus-build-api0 \
    plexus/utils \
    plexus-velocity/plexus-velocity

%{mvn_file} :%{artifactId} %{base_name}/%{artifactId}
pushd %{artifactId}
%{ant} \
    -Dtest.skip=true \
    jar
popd

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{base_name}
install -pm 0644 %{artifactId}/target/%{artifactId}-%{version}.jar %{buildroot}%{_javadir}/%{base_name}/%{artifactId}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{base_name}
%{mvn_install_pom} %{artifactId}/pom.xml %{buildroot}%{_mavenpomdir}/%{base_name}/%{artifactId}.pom
%add_maven_depmap %{base_name}/%{artifactId}.pom %{base_name}/%{artifactId}.jar

%files -f .mfiles
%license LICENSE NOTICE

%changelog
* Tue Oct 29 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.15.1
  * Dependency upgrade
    + MPLUGIN-538: Upgrade to Doxia 2.0.0 GA Stack
    + MPLUGIN-539: Upgrade to Velocity Engine 2.4
* Wed Oct  2 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.15.0
  * New Feature
    + MPLUGIN-529: Add new report goal 'report-no-fork' which
    will not invoke process-classes
  * Improvement
    + MPLUGIN-530: Deprecate o.a.m.plugins.annotations.Component
  * Task
    + MPLUGIN-523: Split Maven3 and Maven4 support
    + MPLUGIN-526: Clean up dependencies reported by
    dependencies:analyze
    + MPLUGIN-528: Tone done report plugin console output
  * Dependency upgrade
    + MPLUGIN-414: Upgrade to Velocity Engine 2.3
    + MPLUGIN-501: Upgrade to Doxia 2.0.0 Milestone Stack
    + MPLUGIN-533: Upgrade to Parent 43
- Modified patch:
  * maven-plugin-plugin-bootstrap-resouces.patch
    + regenerate in cycle with itself
* Wed May 15 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.13.0
- Changes of version 3.13.0
  * Bug
    + MPLUGIN-517: GoalRenderer renderParameterDetails() renders in
    wrong order
    + MPLUGIN-521: Nested types not properly extracted cause
    exception while generating Javadoc URLs
  * Improvement
    + MPLUGIN-520: Get rid of maven-compat classes use
  * Dependency upgrade
    + MPLUGIN-516: Upgrade asmVersion from 9.6 to 9.7
    + MPLUGIN-519: Update to Parent POM 42, prerequisite 3.6.3
- Changes of version 3.12.0
  * Improvement
    + MPLUGIN-510: update plugin system requirements history
    structure
    + MPLUGIN-511: create and share tooling to detect plugin
    prerequisites history
    + MPLUGIN-514: switch dependency schema from png + imagemap to
    svg, and update
- Changes of version 3.11.0
  * Bug
    + MPLUGIN-496: Translation for keys report.plugin.goal.yes,no
    are missing
    + MPLUGIN-499: Deprecate descriptions are missing in description
    table
  * Improvement
    + MPLUGIN-450: Make goal prefix mandatory by default
    + MPLUGIN-474: Improve descriptor docs for requiredJavaVersion
    + MPLUGIN-492: Documentation for plugins in general: Goals
    comprises more than that
    + MPLUGIN-495: WARNINGs based on usage of @Component for
    MavenSession/MavenProject instead of @Parameter
  * Task
    + MPLUGIN-493: Consistently evaluate skip parameter in
    MavenReport#canGenerateReport()
    + MPLUGIN-498: Move section rendering to separate methods
  * Dependency upgrade
    + MPLUGIN-494: Upgrade to Parent 41
    + MPLUGIN-497: Upgrade components
- Changes of version 3.10.2
  * Bug
    + MPLUGIN-484: Downgrade plexus-xml to 3.0.0
  * Dependency upgrade
    + MPLUGIN-485: Upgrade Parent to 40
    + MPLUGIN-487: Bump org.codehaus.plexus:plexus-java from 1.1.2
    to 1.2.0
    + MPLUGIN-488: Bump asmVersion from 9.5 to 9.6
    + MPLUGIN-489: Bump antVersion from 1.10.13 to 1.10.14
    + MPLUGIN-490: Bump org.jsoup:jsoup from 1.16.1 to 1.16.2
    + MPLUGIN-491: Bump org.codehaus.plexus:plexus-testing from
    1.1.0 to 1.2.0
- Changes of version 3.10.1
  * Bug
    + MPLUGIN-482: JavadocSite.createLink() does not consider
    implicit module path prefix
  * Improvement
    + MPLUGIN-442: Rewrite plugin goal documentation generation to
    use supplied sink instead of direct Xdoc
    + MPLUGIN-475: Upgrade to plexus-utils / plexus-xml 4.0.0
    + MPLUGIN-477: Don't add a stray period
  * Dependency upgrade
    + MPLUGIN-478: Upgrade org.junit:junit-bom from 5.9.3 to 5.10.0
    + MPLUGIN-479: Bump org.codehaus.plexus:plexus-archiver from
    4.7.1 to 4.8.0
- Modified patch:
  * maven-plugin-plugin-bootstrap-resouces.patch
    + regenerate with itself
* Wed May  1 2024 Fridrich Strba <fstrba@suse.com>
- Build against the plexus-build-api0 package containing sonatype
  plexus build api
* Tue Apr  2 2024 Fridrich Strba <fstrba@suse.com>
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Tue Feb 20 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Sep 22 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.9.0
- Changes of version 3.9.0
  * Bug
    + MPLUGIN-470: *-mojo.xml (in PluginXdocGenerator) is
    overwritten when multiple locales are defined
    + MPLUGIN-471: Generated table by PluginXdocGenerator does not
    contain default attributes
  * Improvement
    + MPLUGIN-469: Omit empty line in generated help goal output if
    plugin description is empty
    + MPLUGIN-472: Use Plexus I18N rather than fiddling with
  * Task
    + MPLUGIN-467: Remove reporting from maven-plugin-plugin: create
    maven-plugin-report-plugin
  * Dependency upgrade
    + MPLUGIN-468: Upgrade plugins and components (in ITs)
- Changes of version 3.8.2
  * Improvement
    + MPLUGIN-457: Use Resolver API, get rid of localRepository
  * Dependency upgrade
    + MPLUGIN-458: Bump httpcore from 4.4.15 to 4.4.16
    + MPLUGIN-459: Bump httpclient from 4.5.13 to 4.5.14
    + MPLUGIN-460: Bump antVersion from 1.10.12 to 1.10.13
    + MPLUGIN-461: Bump slf4jVersion from 1.7.5 to 1.7.36
    + MPLUGIN-462: Bump plexus-java from 1.1.1 to 1.1.2
    + MPLUGIN-463: Bump plexus-archiver from 4.6.1 to 4.6.3
    + MPLUGIN-464: Bump jsoup from 1.15.3 to 1.15.4
    + MPLUGIN-465: Bump asmVersion from 9.4 to 9.5
    + MPLUGIN-466: Bump assertj-core from 3.23.1 to 3.24.2
- Changes of version 3.8.1
  * Bug
    + MPLUGIN-443: Javadoc reference containing a link label with
    spaces are not detected
    + MPLUGIN-444: JavadocLinkGenerator.createLink: Support nested
    binary class names
    + MPLUGIN-446: ERROR during build of m-plugin-report-p and
    m-plugin-p: Dependencies in wrong scope
    + MPLUGIN-448: "Executes as an aggregator plugin" documentation:
    s/plugin/goal/
    + MPLUGIN-452: Maven scope warning should be logged at WARN
    level
    + MPLUGIN-453: Fix Temporary File Information Disclosure
    Vulnerability
  * New Feature
    + MPLUGIN-441: Support mojos using the new maven v4 api
  * Improvement
    + MPLUGIN-425: Plugin descriptor should contain the
    requiredJavaVersion/requiredMavenVersion
    + MPLUGIN-439: Execute annotation only supports standard
    lifecycle phases due to use of enum
    + MPLUGIN-440: Clarify deprecation of all extractors but the
    maven-plugin-tools-annotations
  * Dependency upgrade
    + MPLUGIN-447: Update to Maven Parent POM 39
    + MPLUGIN-454: Bump junit-bom from 5.9.1 to 5.9.2
    + MPLUGIN-455: Bump plexus-archiver from 4.5.0 to 4.6.1
- Changes of version 3.7.1
  * Bug
    + MPLUGIN-452: Maven scope warning should be logged at WARN
    level
- Changes of version 3.7.0
  * Bug
    + MPLUGIN-298: The plugin descriptor generated by
    plugin:descriptor does not consider @ see javadoc taglets
    + MPLUGIN-394: Report-Mojo doesn't respect input encoding
    + MPLUGIN-403: Generating site reports for plugin results in
    NoSuchMethodError
    + MPLUGIN-404: JDK Requirements in plugin-info.html: Consider
    property "maven.compiler.release"
    + MPLUGIN-420: Parameters documentation inheriting @ since from
    Mojo can be confusing
    + MPLUGIN-428: Don't emit warning for missing javadoc URL of
    primitives
    + MPLUGIN-429: Don't emit warning for missing javadoc URI if no
    javadoc sources are configured
    + MPLUGIN-438: Parameter description should be taken from
    annotated item
  * New Feature
    + MPLUGIN-9: Add link to javadoc in configuration description
    page for user defined types of Mojos.
    + MPLUGIN-396: Allow only @ Deprecated annotation without @
    deprecated javadoc tag
    + MPLUGIN-400: add system requirements history section
    + MPLUGIN-402: report: allow to generate usage section in
    plugin-info.html with true
    + MPLUGIN-419: Allow @ Parameter on setters methods
    + MPLUGIN-423: Extract plugin report into its own plugin
    + MPLUGIN-427: report: Expose generics information of Collection
    and Map types
  * Improvement
    + MPLUGIN-297: plugin-info.html should contain a better Usage
    section
    + MPLUGIN-390: Do not overwrite generate files with no content
    change
    + MPLUGIN-393: Upgrade to JUnit 5 and @ Inject annotations
    + MPLUGIN-398: Support for java 20 - ASM 9.4
    + MPLUGIN-405: Don't print empty Memory, Disk Space in System
    Requirements
    + MPLUGIN-408: simplification in helpmojo build
    + MPLUGIN-411: Get rid of plexus-compiler-manager from tests
    + MPLUGIN-412: Use Maven core artifacts in provided scope
    + MPLUGIN-417: report and descriptor goal need to evaluate
    Javadoc comments differently
    + MPLUGIN-433: Allow to reference aggregator javadoc from plugin
    report
  * Task
    + MPLUGIN-378: Detect legacy/javadoc Mojo definitions, warn to
    use Java 5 annotations
    + MPLUGIN-389: Update level to Java 8
    + MPLUGIN-391: Deprecate scripting support for mojos
    + MPLUGIN-406: Deprecate requirements parameter in report Mojo
    + MPLUGIN-407: Remove duplicate code from PluginReport
    + MPLUGIN-409: Prepare for Doxia (Sitetools) 2.0.0
    + MPLUGIN-430: Fix documentation for maven-plugin-report-plugin
    + MPLUGIN-431: Remove deprecated items from new
    maven-plugin-report-plugin
    + MPLUGIN-432: Improve site build
    + MPLUGIN-434: Improve dependency management
    + MPLUGIN-437: Plugin generator generation fails when the parent
    class comes from a different project
  * Dependency upgrade
    + MPLUGIN-395: Upgrade Maven Reporting API/Impl to 3.1.0
    + MPLUGIN-397: Upgrade Parent to 36
    + MPLUGIN-399: Upgrade project dependencies after JDK 1.8
    + MPLUGIN-413: Bump maven-parent from 36 to 37
    + MPLUGIN-415: Upgrade Maven Reporting API to 3.1.1/Maven
    Reporting Impl to 3.2.0
    + MPLUGIN-422: Upgrade plexus-utils to 3.5.0
- Changes of version 3.6.4
  * What's Changed
    + MPLUGIN-384: restore compatibility with Maven 3 ecosystem
    + MPLUGIN-387: Upgrade dependencies
- Changes of version 3.6.3
  * What's Changed
    + MPLUGIN-383: add prerequisites to plugin pom
    + MPLUGIN-382: exclude dependency in provided scope from plugin
    descriptor
    + Get rid of String.format use
    + Fix this logging as well
    + (doc) Simplify documentation
    + MPLUGIN-386: Exclude maven-archiver and maven-jxr from warning
- Changes of version 3.6.2
  * What's Changed
    + MPLUGIN-374: deprecate unused requiresReports flag
    + MPLUGIN-370: Check that Maven dependencies are provided scope
    + Update ITs
    + use shared gh action
    + MPLUGIN-375: deprecate unsupported Mojo descriptor items
    + Weed out ITs
    + MPLUGIN-377: Upgrade to maven 3.x and avoid using deprecated
    API
    + MPLUGIN-376: Drop legacy dependencies
    + use shared gh action - v1
    + fix wording in javadoc
- Changes of version 3.6.1
  * What's Changed
    + Add missing @OverRide and make methods static
    + MPLUGIN-355: Upgrade to JUnit 4.12
    + upgrade parent POM and other dependencies
    + deps: update plugins
    + MPLUGIN-359: upgrade Doxia Sitetools to 1.9.2 to remove
    dependency on Struts
    + MNGSITE-393: remove Maven 2 info
    + remove unneeded dependency
    + tighten the dependency tree
    + ignore .checkstyle
    + strict dependencies for maven-plugin-tools-annotations
    + (doc) added "help" goal; goal number corrected
    + MPLUGIN-368: Improve @execute(goal...) docs
    + MPLUGIN-367: Improve @execute(lifecycle...) docs
- Modified patches:
  * maven-plugin-plugin-bootstrap-resouces.patch
  * regenerate in cycle
  * 0004-Remove-dependency-on-jtidy.patch
  - > 0002-Remove-dependency-on-jtidy.patch
  * regenerate to changed context
- Removed patches:
  * 0001-Avoid-duplicate-MOJO-parameters.patch
  * 0002-Deal-with-nulls-from-getComment.patch
  * 0003-Port-to-plexus-utils-3.0.24.patch
    + not needed with this version
* Sun Sep  3 2023 Fridrich Strba <fstrba@suse.com>
- Download sources from https://repo1.maven.org
* Mon Jul 24 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * 0004-Remove-dependency-on-jtidy.patch
* Fri May 13 2022 Fridrich Strba <fstrba@suse.com>
- Fix build with modello 2.0.0
* Mon Nov 25 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream 3.6.0
  * allow building with java > 1.8 too against objectweb-asm 7.2
- Removed patch:
  * fix-getPluginsAsMap.patch
    + fix is present in the updated sources
- Modified patch:
  * maven-plugin-plugin-bootstrap-resouces.patch
    + regenerate from the non-bootstrap build to correspond to
    what is generate by the maven-plugin-plugin
* Fri Mar 29 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of a bootstrap version of maven-plugin-plugin
  version 3.5.1
- Added patch:
  * maven-plugin-plugin-bootstrap-resouces.patch
    + Add to the build pre-generated resources that need, in a
    circular way, maven and maven-plugin-plugin for their
    generation.
